@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCEATTACHMENT_H
-#define INCIDENCEEDITOR_INCIDENCEATTACHMENT_H
+#pragma once
 
 #include "incidenceeditor-ng.h"
 class QUrl;
@@ -38,9 +37,9 @@ public:
 
     void load(const KCalendarCore::Incidence::Ptr &incidence) override;
     void save(const KCalendarCore::Incidence::Ptr &incidence) override;
-    Q_REQUIRED_RESULT bool isDirty() const override;
+    [[nodiscard]] bool isDirty() const override;
 
-    Q_REQUIRED_RESULT int attachmentCount() const;
+    [[nodiscard]] int attachmentCount() const;
 
 Q_SIGNALS:
     void attachmentCountChanged(int newCount);
@@ -74,7 +73,7 @@ private:
     AttachmentIconView *mAttachmentView = nullptr;
     Ui::EventOrTodoDesktop *const mUi;
 
-    QMenu *mPopupMenu = nullptr;
+    QMenu *const mPopupMenu;
     QAction *mOpenAction = nullptr;
     QAction *mSaveAsAction = nullptr;
 #ifndef QT_NO_CLIPBOARD
@@ -85,5 +84,3 @@ private:
     QAction *mEditAction = nullptr;
 };
 }
-
-#endif
