@@ -72,7 +72,7 @@ IncidenceRecurrence::IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventO
     , mMonthlyInitialType(0)
     , mYearlyInitialType(0)
 {
-    setObjectName(QStringLiteral("IncidenceRecurrence"));
+    setObjectName(QLatin1StringView("IncidenceRecurrence"));
     // Set some sane defaults
     mUi->mRecurrenceTypeCombo->setCurrentIndex(RecurrenceTypeNone);
     mUi->mRecurrenceEndCombo->setCurrentIndex(RecurrenceEndNever);
@@ -896,7 +896,6 @@ void IncidenceRecurrence::setExceptionDates(const KCalendarCore::DateList &dates
 {
     mUi->mExceptionList->clear();
     mExceptionDates.clear();
-    KCalendarCore::DateList::ConstIterator dit;
     for (const auto &d : dates) {
         mUi->mExceptionList->addItem(QLocale().toString(d));
         mExceptionDates.append(d);
