@@ -4,24 +4,21 @@
  * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
-#ifndef INCIDENCEEDITOR_INDIVIDUALMAILDIALOG_H
-#define INCIDENCEEDITOR_INDIVIDUALMAILDIALOG_H
-
+#pragma once
+#include "incidenceeditor_private_export.h"
 #include <KCalendarCore/Attendee>
 #include <QDialog>
 
-#include <QComboBox>
-#include <QDialogButtonBox>
-
 class KGuiItem;
 
 class TestIndividualMailDialog;
-
+class QDialogButtonBox;
+class QComboBox;
 namespace IncidenceEditorNG
 {
 // Shows a dialog with a question and the option to select which attendee should get the mail or to open a composer for him.
 // Used to get individual mails for attendees of an event.
-class IndividualMailDialog : public QDialog
+class INCIDENCEEDITOR_TESTS_EXPORT IndividualMailDialog : public QDialog
 {
     Q_OBJECT
     friend class ::TestIndividualMailDialog;
@@ -39,8 +36,8 @@ public:
                                   QWidget *parent = nullptr);
     ~IndividualMailDialog() override;
 
-    Q_REQUIRED_RESULT KCalendarCore::Attendee::List editAttendees() const;
-    Q_REQUIRED_RESULT KCalendarCore::Attendee::List updateAttendees() const;
+    [[nodiscard]] KCalendarCore::Attendee::List editAttendees() const;
+    [[nodiscard]] KCalendarCore::Attendee::List updateAttendees() const;
 
 private:
     void updateButtonState();
@@ -50,5 +47,3 @@ private:
     QWidget *m_detailsWidget = nullptr;
 };
 }
-
-#endif
